@@ -102,6 +102,34 @@ K1
 K2
 K1+K2
 
+## ------------------------------------------------------------------------
+U <- ktensor(spray(cbind(1:4,2:5),1:4))
+U
+
+## ------------------------------------------------------------------------
+as.symbolic(U)
+
+## ------------------------------------------------------------------------
+K <- kform_general(3,2,1:3)
+K
+as.symbolic(K,d="d",symbols=letters[23:26])
+
+## ------------------------------------------------------------------------
+(o <- rform())  # a random 3-form
+V <- matrix(runif(21),ncol=3)
+LHS <- as.function(o)(V)
+RHS <- as.function(contract(o,V[,1]))(V[,-1])
+c(LHS=LHS,RHS=RHS,diff=LHS-RHS)
+
+## ------------------------------------------------------------------------
+as.function(contract(o,V[,1:2]))(V[,-(1:2),drop=FALSE])
+
+## ------------------------------------------------------------------------
+contract(o,V)
+
+## ------------------------------------------------------------------------
+contract(o,V,lose=FALSE)
+
 ## ------------------------------------------------------------------------
 grad(c(0.4,0.1,-3.2,1.5))
 
